All of the people who have made at least one contribution to versioned-hdf5.
Authors are sorted by number of commits.

* Aaron Meurer
* Melissa Weber Mendonça
* Arvid Bessen
* Saul Shanabrook
* Anthony Scopatz
* Marc Udoff
